abacusai.unified_connector — AbacusAI documentation

# abacusai.unified_connector

## Classes

`UnifiedConnector` | A unified connector that can handle both application and database connectors.

## Module Contents

class abacusai.unified_connector.UnifiedConnector(client, applicationConnectorId=None, databaseConnectorId=None, service=None, name=None, createdAt=None, status=None, auth=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A unified connector that can handle both application and database connectors.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - applicationConnectorId (str) – The unique ID for the connection.

    - databaseConnectorId (str) – The unique ID for the connection.

    - service (str) – The service this connection connects to

    - name (str) – A user-friendly name for the service

    - createdAt (str) – When the API key was created

    - status (str) – The status of the Application Connector

    - auth (dict) – Non-secret connection information for this connector

  application_connector_id = None
  database_connector_id = None
  service = None
  name = None
  created_at = None
  status = None
  auth = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict